@@ -5,6 +5,7 @@
 #
 
 from hachoir_core.tools import alignValue
+from hachoir_core.stream.input import FileFromInputStream
 
 def field_index(field_set, field):
     return field_set._fields.index(field._getName())
@@ -34,7 +35,9 @@ def convert_size(from_field, to_type):
     else:
         return from_field._getSize() / 8
 
-def save_field_to_disk(field, src_stream, dest_path):
+def save_substream_to_disk(field, dest_path):
     dest_stream = open(dest_path, 'wb')
-    src_stream.seek(field._getAbsoluteAddress() / 8)
-    dest_stream.write(src_stream.read(alignValue(field._getSize(), 8) / 8))
+    f = FileFromInputStream(field.getSubIStream())
+    dest_stream.write(f.read())
+    dest_stream.close()
+
